// Example 905A
// Example of the DHT11 temperature/humidity sensor
// Akinori Tsuji, October 2015
#include <Wire.h>
#include <ST7032.h>
#include <DHT.h>

// LCD
ST7032 lcd;

// Sensor
DHT dht(9, DHT11);

void setup() {
  lcd.begin(8, 2); // 液晶の表示開始
  lcd.setContrast(30); // 液晶のコントラスト
  lcd.clear();

  dht.begin(); // DHT11計測開始
}

void loop() {
  // センサによる計測
  int d = dht.readTemperature(); // 温度計測
  int h = dht.readHumidity() ;   // 湿度計測

  // 計測結果の処理
  float t = average(d); // 温度の平均

  // 液晶に結果表示
  lcd.setCursor(0, 0); // 0列, 1行にセット
  lcd.print(t);
  lcd.print((char)0xDF); // 度
  lcd.print("C");
  lcd.setCursor(0, 1); // 0列, 1行にセット
  lcd.print(h);
  lcd.print("%");

  delay(2000); // 2秒以上待つ
}


#define N  32 // サンプル数
int data[N];  // データ格納用配列

float average(int t) {
  float sum;

  data[0] = t; // 最新のデータ

  // 平均処理
  sum = 0;
  for (int i=0; i<N; i++) {
    sum += data[i];
  }
  sum /= N;

  // 配列内の要素を一ずつずらす
  for (int i=N-1; i>0; i--) {
    data[i] = data[i-1];
  }

  return sum;
}

