// Example 906
// Example of the DHT11 temperature/humidity sensor
// Akinori Tsuji, October 2015
#include <Wire.h>
#include <ST7032.h>
#include <DHT.h>
#include <FastLED.h>

// LCD
ST7032 lcd;

// Sensor
DHT dht(9, DHT11);

// LED
const int DATA_PIN = 4;
#define NUM_LEDS 1
CRGB leds[NUM_LEDS];

long time; // 時間計測用変数
float hic; // ヒートインデクス

void setup() {
  lcd.begin(8, 2);
  lcd.setContrast(30);
  lcd.clear();

  FastLED.addLeds<WS2811, DATA_PIN, RGB>(leds, NUM_LEDS);
  FastLED.setBrightness(255); // 0-255
  leds[0] = CRGB(0,0,0); // 消灯
  FastLED.show();

  dht.begin();
  time = millis(); // 時間を記録
}

void loop() {
  // 現在時間(millis)と前の時間(time)を比較
  // 2000ms経過したときのみ計測
  if (millis() - time > 2000) {
    float t = dht.readTemperature();
    float h = dht.readHumidity();
    hic = dht.computeHeatIndex(t, h, false);
    time = millis(); // 時間を記録

    lcd.setCursor(0, 0);
    lcd.print((int)t);
    lcd.print((char)(0xDF)); 
    lcd.print("C");
    lcd.print(" ");
    lcd.print((int)h);
    lcd.print("%");    

    lcd.setCursor(0, 1);
    lcd.print("HI:");
    lcd.print(hic);

    int hue = map(hic, 27, 59, 64, 0); // yellow to red
    leds[0] = CHSV(hue, 255, 255);
    FastLED.show();
  }
}


